@@ -111,7 +111,7 @@ class Act():
         except requests.exceptions.ConnectionError:
             s= 'Failure to load the URI at %s' % (uwsgi_uri)
             s+= 'Hint: this is probably a stale port.\nTry reloading the Act by touching its .ini file.\n'
-            s+= 'Or, wait a few more seconds and try "(self).get_uwsgi_port() again"
+            s+= 'Or, wait a few more seconds and try "(self).get_uwsgi_port() again'
             print s
 
             self.uwsgi_ip = None
