@@ -6,4 +6,5 @@ DEBUG = True
 STATIC_URL = '/static/'
 STATIC_ROOT = os.path.abspath(os.path.join(VENUE_ROOT,'static'))
 
-
+#APPS specifict to this venue which should be appended to INSTALLED_APPS
+VENUE_APPS = []
\ No newline at end of file
